Documentation
¶
Index ¶
- Variables
- func ConfigureGlobals(app *kingpin.Application)
- func ConfigureProxyCommand(app *kingpin.Application)
- func ConfigureSocksCommand(app *kingpin.Application)
- func ConfigureWebCommand(app *kingpin.Application)
- func ProxyCommand(ctx internal.Context, cfg ProxyCommandInput) error
- func SocksCommand(ctx internal.Context, cfg SocksCommandInput) error
- func WebCommand(ctx internal.Context, cfg WebCommandInput) error
- type ProxyCommandInput
- type SocksCommandInput
- type WebCommandInput
Constants ¶
This section is empty.
Variables ¶
var GlobalFlags struct { Debug bool RedisAddress string }
GlobalFlags are going to store some data used by all of the commands.
Functions ¶
func ConfigureGlobals ¶
func ConfigureGlobals(app *kingpin.Application)
ConfigureGlobals should fill in the above struct with usable data values.
func ConfigureProxyCommand ¶
func ConfigureProxyCommand(app *kingpin.Application)
ConfigureProxyCommand should fill in the above input struct with some usable values. It is also responsible for creating the context to be used within the app itself.
func ConfigureSocksCommand ¶
func ConfigureSocksCommand(app *kingpin.Application)
ConfigureSocksCommand should fill in the above input struct with some usable values. It is also responsible for creating the context to be used within the app itself.
func ConfigureWebCommand ¶
func ConfigureWebCommand(app *kingpin.Application)
ConfigureWebCommand should fill in the above input struct with some usable values. It is also responsible for creating the context to be used within the app itself.
func ProxyCommand ¶
func ProxyCommand(ctx internal.Context, cfg ProxyCommandInput) error
ProxyCommand is the main brain behind this commands. It will start the HTTP Proxy server and hang tight accepting, rejecting and working with requests.
func SocksCommand ¶
func SocksCommand(ctx internal.Context, cfg SocksCommandInput) error
SocksCommand is the main brain behind this commands. It will start the SOCKS5 Proxy server and hang tight accepting, rejecting and working with requests.
func WebCommand ¶
func WebCommand(ctx internal.Context, cfg WebCommandInput) error
WebCommand is the main brain behind this commands. It will start the web frontend and hang tight accepting, rejecting and working with requests. It will take the job of authenticating with OIDC and generating bunch of secrets for the IAP users.
Types ¶
type ProxyCommandInput ¶
ProxyCommandInput is a configuration only to be used by this particular command.
type SocksCommandInput ¶
SocksCommandInput is a configuration only to be used by this particular command.
type WebCommandInput ¶
type WebCommandInput struct {
Port uint16
}
WebCommandInput is a configuration only to be used by this particular command.